# coding: utf-8

"""
    SendinBlue API

    SendinBlue provide a RESTFul API that can be used with any languages. With this API, you will be able to :   - Manage your campaigns and get the statistics   - Manage your contacts   - Send transactional Emails and SMS   - and much more...  You can download our wrappers at https://github.com/orgs/sendinblue  **Possible responses**   | Code | Message |   | :-------------: | ------------- |   | 200  | OK. Successful Request  |   | 201  | OK. Successful Creation |   | 202  | OK. Request accepted |   | 204  | OK. Successful Update/Deletion  |   | 400  | Error. Bad Request  |   | 401  | Error. Authentication Needed  |   | 402  | Error. Not enough credit, plan upgrade needed  |   | 403  | Error. Permission denied  |   | 404  | Error. Object does not exist |   | 405  | Error. Method not allowed  |   # noqa: E501

    OpenAPI spec version: 3.0.0
    Contact: contact@sendinblue.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from sib_api_v3_sdk.models.get_smtp_template_overview_sender import GetSmtpTemplateOverviewSender  # noqa: F401,E501


class GetSmtpTemplateOverview(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'name': 'str',
        'subject': 'str',
        'is_active': 'bool',
        'test_sent': 'bool',
        'sender': 'GetSmtpTemplateOverviewSender',
        'reply_to': 'str',
        'to_field': 'str',
        'tag': 'str',
        'html_content': 'str',
        'created_at': 'datetime',
        'modified_at': 'datetime'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'subject': 'subject',
        'is_active': 'isActive',
        'test_sent': 'testSent',
        'sender': 'sender',
        'reply_to': 'replyTo',
        'to_field': 'toField',
        'tag': 'tag',
        'html_content': 'htmlContent',
        'created_at': 'createdAt',
        'modified_at': 'modifiedAt'
    }

    def __init__(self, id=None, name=None, subject=None, is_active=None, test_sent=None, sender=None, reply_to=None, to_field=None, tag=None, html_content=None, created_at=None, modified_at=None):  # noqa: E501
        """GetSmtpTemplateOverview - a model defined in Swagger"""  # noqa: E501

        self._id = None
        self._name = None
        self._subject = None
        self._is_active = None
        self._test_sent = None
        self._sender = None
        self._reply_to = None
        self._to_field = None
        self._tag = None
        self._html_content = None
        self._created_at = None
        self._modified_at = None
        self.discriminator = None

        self.id = id
        self.name = name
        self.subject = subject
        self.is_active = is_active
        self.test_sent = test_sent
        self.sender = sender
        self.reply_to = reply_to
        self.to_field = to_field
        self.tag = tag
        self.html_content = html_content
        self.created_at = created_at
        self.modified_at = modified_at

    @property
    def id(self):
        """Gets the id of this GetSmtpTemplateOverview.  # noqa: E501

        ID of the template  # noqa: E501

        :return: The id of this GetSmtpTemplateOverview.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this GetSmtpTemplateOverview.

        ID of the template  # noqa: E501

        :param id: The id of this GetSmtpTemplateOverview.  # noqa: E501
        :type: int
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def name(self):
        """Gets the name of this GetSmtpTemplateOverview.  # noqa: E501

        Name of the template  # noqa: E501

        :return: The name of this GetSmtpTemplateOverview.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this GetSmtpTemplateOverview.

        Name of the template  # noqa: E501

        :param name: The name of this GetSmtpTemplateOverview.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def subject(self):
        """Gets the subject of this GetSmtpTemplateOverview.  # noqa: E501

        Subject of the template  # noqa: E501

        :return: The subject of this GetSmtpTemplateOverview.  # noqa: E501
        :rtype: str
        """
        return self._subject

    @subject.setter
    def subject(self, subject):
        """Sets the subject of this GetSmtpTemplateOverview.

        Subject of the template  # noqa: E501

        :param subject: The subject of this GetSmtpTemplateOverview.  # noqa: E501
        :type: str
        """
        if subject is None:
            raise ValueError("Invalid value for `subject`, must not be `None`")  # noqa: E501

        self._subject = subject

    @property
    def is_active(self):
        """Gets the is_active of this GetSmtpTemplateOverview.  # noqa: E501

        Status of template (true=active, false=inactive)  # noqa: E501

        :return: The is_active of this GetSmtpTemplateOverview.  # noqa: E501
        :rtype: bool
        """
        return self._is_active

    @is_active.setter
    def is_active(self, is_active):
        """Sets the is_active of this GetSmtpTemplateOverview.

        Status of template (true=active, false=inactive)  # noqa: E501

        :param is_active: The is_active of this GetSmtpTemplateOverview.  # noqa: E501
        :type: bool
        """
        if is_active is None:
            raise ValueError("Invalid value for `is_active`, must not be `None`")  # noqa: E501

        self._is_active = is_active

    @property
    def test_sent(self):
        """Gets the test_sent of this GetSmtpTemplateOverview.  # noqa: E501

        Status of test sending for the template (true=test email has been sent, false=test email has not been sent)  # noqa: E501

        :return: The test_sent of this GetSmtpTemplateOverview.  # noqa: E501
        :rtype: bool
        """
        return self._test_sent

    @test_sent.setter
    def test_sent(self, test_sent):
        """Sets the test_sent of this GetSmtpTemplateOverview.

        Status of test sending for the template (true=test email has been sent, false=test email has not been sent)  # noqa: E501

        :param test_sent: The test_sent of this GetSmtpTemplateOverview.  # noqa: E501
        :type: bool
        """
        if test_sent is None:
            raise ValueError("Invalid value for `test_sent`, must not be `None`")  # noqa: E501

        self._test_sent = test_sent

    @property
    def sender(self):
        """Gets the sender of this GetSmtpTemplateOverview.  # noqa: E501


        :return: The sender of this GetSmtpTemplateOverview.  # noqa: E501
        :rtype: GetSmtpTemplateOverviewSender
        """
        return self._sender

    @sender.setter
    def sender(self, sender):
        """Sets the sender of this GetSmtpTemplateOverview.


        :param sender: The sender of this GetSmtpTemplateOverview.  # noqa: E501
        :type: GetSmtpTemplateOverviewSender
        """
        if sender is None:
            raise ValueError("Invalid value for `sender`, must not be `None`")  # noqa: E501

        self._sender = sender

    @property
    def reply_to(self):
        """Gets the reply_to of this GetSmtpTemplateOverview.  # noqa: E501

        Email defined as the \"Reply to\" for the template  # noqa: E501

        :return: The reply_to of this GetSmtpTemplateOverview.  # noqa: E501
        :rtype: str
        """
        return self._reply_to

    @reply_to.setter
    def reply_to(self, reply_to):
        """Sets the reply_to of this GetSmtpTemplateOverview.

        Email defined as the \"Reply to\" for the template  # noqa: E501

        :param reply_to: The reply_to of this GetSmtpTemplateOverview.  # noqa: E501
        :type: str
        """
        if reply_to is None:
            raise ValueError("Invalid value for `reply_to`, must not be `None`")  # noqa: E501

        self._reply_to = reply_to

    @property
    def to_field(self):
        """Gets the to_field of this GetSmtpTemplateOverview.  # noqa: E501

        Customisation of the \"to\" field for the template  # noqa: E501

        :return: The to_field of this GetSmtpTemplateOverview.  # noqa: E501
        :rtype: str
        """
        return self._to_field

    @to_field.setter
    def to_field(self, to_field):
        """Sets the to_field of this GetSmtpTemplateOverview.

        Customisation of the \"to\" field for the template  # noqa: E501

        :param to_field: The to_field of this GetSmtpTemplateOverview.  # noqa: E501
        :type: str
        """
        if to_field is None:
            raise ValueError("Invalid value for `to_field`, must not be `None`")  # noqa: E501

        self._to_field = to_field

    @property
    def tag(self):
        """Gets the tag of this GetSmtpTemplateOverview.  # noqa: E501

        Tag of the template  # noqa: E501

        :return: The tag of this GetSmtpTemplateOverview.  # noqa: E501
        :rtype: str
        """
        return self._tag

    @tag.setter
    def tag(self, tag):
        """Sets the tag of this GetSmtpTemplateOverview.

        Tag of the template  # noqa: E501

        :param tag: The tag of this GetSmtpTemplateOverview.  # noqa: E501
        :type: str
        """
        if tag is None:
            raise ValueError("Invalid value for `tag`, must not be `None`")  # noqa: E501

        self._tag = tag

    @property
    def html_content(self):
        """Gets the html_content of this GetSmtpTemplateOverview.  # noqa: E501

        HTML content of the template  # noqa: E501

        :return: The html_content of this GetSmtpTemplateOverview.  # noqa: E501
        :rtype: str
        """
        return self._html_content

    @html_content.setter
    def html_content(self, html_content):
        """Sets the html_content of this GetSmtpTemplateOverview.

        HTML content of the template  # noqa: E501

        :param html_content: The html_content of this GetSmtpTemplateOverview.  # noqa: E501
        :type: str
        """
        if html_content is None:
            raise ValueError("Invalid value for `html_content`, must not be `None`")  # noqa: E501

        self._html_content = html_content

    @property
    def created_at(self):
        """Gets the created_at of this GetSmtpTemplateOverview.  # noqa: E501

        Creation UTC date-time of the template (YYYY-MM-DDTHH:mm:ss.SSSZ)  # noqa: E501

        :return: The created_at of this GetSmtpTemplateOverview.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this GetSmtpTemplateOverview.

        Creation UTC date-time of the template (YYYY-MM-DDTHH:mm:ss.SSSZ)  # noqa: E501

        :param created_at: The created_at of this GetSmtpTemplateOverview.  # noqa: E501
        :type: datetime
        """
        if created_at is None:
            raise ValueError("Invalid value for `created_at`, must not be `None`")  # noqa: E501

        self._created_at = created_at

    @property
    def modified_at(self):
        """Gets the modified_at of this GetSmtpTemplateOverview.  # noqa: E501

        Last modification UTC date-time of the template (YYYY-MM-DDTHH:mm:ss.SSSZ)  # noqa: E501

        :return: The modified_at of this GetSmtpTemplateOverview.  # noqa: E501
        :rtype: datetime
        """
        return self._modified_at

    @modified_at.setter
    def modified_at(self, modified_at):
        """Sets the modified_at of this GetSmtpTemplateOverview.

        Last modification UTC date-time of the template (YYYY-MM-DDTHH:mm:ss.SSSZ)  # noqa: E501

        :param modified_at: The modified_at of this GetSmtpTemplateOverview.  # noqa: E501
        :type: datetime
        """
        if modified_at is None:
            raise ValueError("Invalid value for `modified_at`, must not be `None`")  # noqa: E501

        self._modified_at = modified_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GetSmtpTemplateOverview):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    SendinBlue API

    SendinBlue provide a RESTFul API that can be used with any languages. With this API, you will be able to :   - Manage your campaigns and get the statistics   - Manage your contacts   - Send transactional Emails and SMS   - and much more...  You can download our wrappers at https://github.com/orgs/sendinblue  **Possible responses**   | Code | Message |   | :-------------: | ------------- |   | 200  | OK. Successful Request  |   | 201  | OK. Successful Creation |   | 202  | OK. Request accepted |   | 204  | OK. Successful Update/Deletion  |   | 400  | Error. Bad Request  |   | 401  | Error. Authentication Needed  |   | 402  | Error. Not enough credit, plan upgrade needed  |   | 403  | Error. Permission denied  |   | 404  | Error. Object does not exist |   | 405  | Error. Method not allowed  |   # noqa: E501

    OpenAPI spec version: 3.0.0
    Contact: contact@sendinblue.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class GetReportsReports(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'date': 'date',
        'requests': 'int',
        'delivered': 'int',
        'hard_bounces': 'int',
        'soft_bounces': 'int',
        'clicks': 'int',
        'unique_clicks': 'int',
        'opens': 'int',
        'unique_opens': 'int',
        'spam_reports': 'int',
        'blocked': 'int',
        'invalid': 'int',
        'unsubscribed': 'int'
    }

    attribute_map = {
        'date': 'date',
        'requests': 'requests',
        'delivered': 'delivered',
        'hard_bounces': 'hardBounces',
        'soft_bounces': 'softBounces',
        'clicks': 'clicks',
        'unique_clicks': 'uniqueClicks',
        'opens': 'opens',
        'unique_opens': 'uniqueOpens',
        'spam_reports': 'spamReports',
        'blocked': 'blocked',
        'invalid': 'invalid',
        'unsubscribed': 'unsubscribed'
    }

    def __init__(self, date=None, requests=None, delivered=None, hard_bounces=None, soft_bounces=None, clicks=None, unique_clicks=None, opens=None, unique_opens=None, spam_reports=None, blocked=None, invalid=None, unsubscribed=None):  # noqa: E501
        """GetReportsReports - a model defined in Swagger"""  # noqa: E501

        self._date = None
        self._requests = None
        self._delivered = None
        self._hard_bounces = None
        self._soft_bounces = None
        self._clicks = None
        self._unique_clicks = None
        self._opens = None
        self._unique_opens = None
        self._spam_reports = None
        self._blocked = None
        self._invalid = None
        self._unsubscribed = None
        self.discriminator = None

        self.date = date
        self.requests = requests
        self.delivered = delivered
        self.hard_bounces = hard_bounces
        self.soft_bounces = soft_bounces
        self.clicks = clicks
        self.unique_clicks = unique_clicks
        self.opens = opens
        self.unique_opens = unique_opens
        self.spam_reports = spam_reports
        self.blocked = blocked
        self.invalid = invalid
        self.unsubscribed = unsubscribed

    @property
    def date(self):
        """Gets the date of this GetReportsReports.  # noqa: E501

        Date of the statistics  # noqa: E501

        :return: The date of this GetReportsReports.  # noqa: E501
        :rtype: date
        """
        return self._date

    @date.setter
    def date(self, date):
        """Sets the date of this GetReportsReports.

        Date of the statistics  # noqa: E501

        :param date: The date of this GetReportsReports.  # noqa: E501
        :type: date
        """
        if date is None:
            raise ValueError("Invalid value for `date`, must not be `None`")  # noqa: E501

        self._date = date

    @property
    def requests(self):
        """Gets the requests of this GetReportsReports.  # noqa: E501

        Number of requests for the date  # noqa: E501

        :return: The requests of this GetReportsReports.  # noqa: E501
        :rtype: int
        """
        return self._requests

    @requests.setter
    def requests(self, requests):
        """Sets the requests of this GetReportsReports.

        Number of requests for the date  # noqa: E501

        :param requests: The requests of this GetReportsReports.  # noqa: E501
        :type: int
        """
        if requests is None:
            raise ValueError("Invalid value for `requests`, must not be `None`")  # noqa: E501

        self._requests = requests

    @property
    def delivered(self):
        """Gets the delivered of this GetReportsReports.  # noqa: E501

        Number of delivered emails for the date  # noqa: E501

        :return: The delivered of this GetReportsReports.  # noqa: E501
        :rtype: int
        """
        return self._delivered

    @delivered.setter
    def delivered(self, delivered):
        """Sets the delivered of this GetReportsReports.

        Number of delivered emails for the date  # noqa: E501

        :param delivered: The delivered of this GetReportsReports.  # noqa: E501
        :type: int
        """
        if delivered is None:
            raise ValueError("Invalid value for `delivered`, must not be `None`")  # noqa: E501

        self._delivered = delivered

    @property
    def hard_bounces(self):
        """Gets the hard_bounces of this GetReportsReports.  # noqa: E501

        Number of hardbounces for the date  # noqa: E501

        :return: The hard_bounces of this GetReportsReports.  # noqa: E501
        :rtype: int
        """
        return self._hard_bounces

    @hard_bounces.setter
    def hard_bounces(self, hard_bounces):
        """Sets the hard_bounces of this GetReportsReports.

        Number of hardbounces for the date  # noqa: E501

        :param hard_bounces: The hard_bounces of this GetReportsReports.  # noqa: E501
        :type: int
        """
        if hard_bounces is None:
            raise ValueError("Invalid value for `hard_bounces`, must not be `None`")  # noqa: E501

        self._hard_bounces = hard_bounces

    @property
    def soft_bounces(self):
        """Gets the soft_bounces of this GetReportsReports.  # noqa: E501

        Number of softbounces for the date  # noqa: E501

        :return: The soft_bounces of this GetReportsReports.  # noqa: E501
        :rtype: int
        """
        return self._soft_bounces

    @soft_bounces.setter
    def soft_bounces(self, soft_bounces):
        """Sets the soft_bounces of this GetReportsReports.

        Number of softbounces for the date  # noqa: E501

        :param soft_bounces: The soft_bounces of this GetReportsReports.  # noqa: E501
        :type: int
        """
        if soft_bounces is None:
            raise ValueError("Invalid value for `soft_bounces`, must not be `None`")  # noqa: E501

        self._soft_bounces = soft_bounces

    @property
    def clicks(self):
        """Gets the clicks of this GetReportsReports.  # noqa: E501

        Number of clicks for the date  # noqa: E501

        :return: The clicks of this GetReportsReports.  # noqa: E501
        :rtype: int
        """
        return self._clicks

    @clicks.setter
    def clicks(self, clicks):
        """Sets the clicks of this GetReportsReports.

        Number of clicks for the date  # noqa: E501

        :param clicks: The clicks of this GetReportsReports.  # noqa: E501
        :type: int
        """
        if clicks is None:
            raise ValueError("Invalid value for `clicks`, must not be `None`")  # noqa: E501

        self._clicks = clicks

    @property
    def unique_clicks(self):
        """Gets the unique_clicks of this GetReportsReports.  # noqa: E501

        Number of unique clicks for the date  # noqa: E501

        :return: The unique_clicks of this GetReportsReports.  # noqa: E501
        :rtype: int
        """
        return self._unique_clicks

    @unique_clicks.setter
    def unique_clicks(self, unique_clicks):
        """Sets the unique_clicks of this GetReportsReports.

        Number of unique clicks for the date  # noqa: E501

        :param unique_clicks: The unique_clicks of this GetReportsReports.  # noqa: E501
        :type: int
        """
        if unique_clicks is None:
            raise ValueError("Invalid value for `unique_clicks`, must not be `None`")  # noqa: E501

        self._unique_clicks = unique_clicks

    @property
    def opens(self):
        """Gets the opens of this GetReportsReports.  # noqa: E501

        Number of openings for the date  # noqa: E501

        :return: The opens of this GetReportsReports.  # noqa: E501
        :rtype: int
        """
        return self._opens

    @opens.setter
    def opens(self, opens):
        """Sets the opens of this GetReportsReports.

        Number of openings for the date  # noqa: E501

        :param opens: The opens of this GetReportsReports.  # noqa: E501
        :type: int
        """
        if opens is None:
            raise ValueError("Invalid value for `opens`, must not be `None`")  # noqa: E501

        self._opens = opens

    @property
    def unique_opens(self):
        """Gets the unique_opens of this GetReportsReports.  # noqa: E501

        Number of unique openings for the date  # noqa: E501

        :return: The unique_opens of this GetReportsReports.  # noqa: E501
        :rtype: int
        """
        return self._unique_opens

    @unique_opens.setter
    def unique_opens(self, unique_opens):
        """Sets the unique_opens of this GetReportsReports.

        Number of unique openings for the date  # noqa: E501

        :param unique_opens: The unique_opens of this GetReportsReports.  # noqa: E501
        :type: int
        """
        if unique_opens is None:
            raise ValueError("Invalid value for `unique_opens`, must not be `None`")  # noqa: E501

        self._unique_opens = unique_opens

    @property
    def spam_reports(self):
        """Gets the spam_reports of this GetReportsReports.  # noqa: E501

        Number of complaints (spam reports) for the date  # noqa: E501

        :return: The spam_reports of this GetReportsReports.  # noqa: E501
        :rtype: int
        """
        return self._spam_reports

    @spam_reports.setter
    def spam_reports(self, spam_reports):
        """Sets the spam_reports of this GetReportsReports.

        Number of complaints (spam reports) for the date  # noqa: E501

        :param spam_reports: The spam_reports of this GetReportsReports.  # noqa: E501
        :type: int
        """
        if spam_reports is None:
            raise ValueError("Invalid value for `spam_reports`, must not be `None`")  # noqa: E501

        self._spam_reports = spam_reports

    @property
    def blocked(self):
        """Gets the blocked of this GetReportsReports.  # noqa: E501

        Number of blocked emails for the date  # noqa: E501

        :return: The blocked of this GetReportsReports.  # noqa: E501
        :rtype: int
        """
        return self._blocked

    @blocked.setter
    def blocked(self, blocked):
        """Sets the blocked of this GetReportsReports.

        Number of blocked emails for the date  # noqa: E501

        :param blocked: The blocked of this GetReportsReports.  # noqa: E501
        :type: int
        """
        if blocked is None:
            raise ValueError("Invalid value for `blocked`, must not be `None`")  # noqa: E501

        self._blocked = blocked

    @property
    def invalid(self):
        """Gets the invalid of this GetReportsReports.  # noqa: E501

        Number of invalid emails for the date  # noqa: E501

        :return: The invalid of this GetReportsReports.  # noqa: E501
        :rtype: int
        """
        return self._invalid

    @invalid.setter
    def invalid(self, invalid):
        """Sets the invalid of this GetReportsReports.

        Number of invalid emails for the date  # noqa: E501

        :param invalid: The invalid of this GetReportsReports.  # noqa: E501
        :type: int
        """
        if invalid is None:
            raise ValueError("Invalid value for `invalid`, must not be `None`")  # noqa: E501

        self._invalid = invalid

    @property
    def unsubscribed(self):
        """Gets the unsubscribed of this GetReportsReports.  # noqa: E501

        Number of unsubscribed emails for the date  # noqa: E501

        :return: The unsubscribed of this GetReportsReports.  # noqa: E501
        :rtype: int
        """
        return self._unsubscribed

    @unsubscribed.setter
    def unsubscribed(self, unsubscribed):
        """Sets the unsubscribed of this GetReportsReports.

        Number of unsubscribed emails for the date  # noqa: E501

        :param unsubscribed: The unsubscribed of this GetReportsReports.  # noqa: E501
        :type: int
        """
        if unsubscribed is None:
            raise ValueError("Invalid value for `unsubscribed`, must not be `None`")  # noqa: E501

        self._unsubscribed = unsubscribed

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GetReportsReports):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    SendinBlue API

    SendinBlue provide a RESTFul API that can be used with any languages. With this API, you will be able to :   - Manage your campaigns and get the statistics   - Manage your contacts   - Send transactional Emails and SMS   - and much more...  You can download our wrappers at https://github.com/orgs/sendinblue  **Possible responses**   | Code | Message |   | :-------------: | ------------- |   | 200  | OK. Successful Request  |   | 201  | OK. Successful Creation |   | 202  | OK. Request accepted |   | 204  | OK. Successful Update/Deletion  |   | 400  | Error. Bad Request  |   | 401  | Error. Authentication Needed  |   | 402  | Error. Not enough credit, plan upgrade needed  |   | 403  | Error. Permission denied  |   | 404  | Error. Object does not exist |   | 405  | Error. Method not allowed  |   # noqa: E501

    OpenAPI spec version: 3.0.0
    Contact: contact@sendinblue.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from sib_api_v3_sdk.models.get_ip import GetIp  # noqa: F401,E501


class GetIps(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'ips': 'list[GetIp]'
    }

    attribute_map = {
        'ips': 'ips'
    }

    def __init__(self, ips=None):  # noqa: E501
        """GetIps - a model defined in Swagger"""  # noqa: E501

        self._ips = None
        self.discriminator = None

        self.ips = ips

    @property
    def ips(self):
        """Gets the ips of this GetIps.  # noqa: E501

        Dedicated IP(s) available on your account  # noqa: E501

        :return: The ips of this GetIps.  # noqa: E501
        :rtype: list[GetIp]
        """
        return self._ips

    @ips.setter
    def ips(self, ips):
        """Sets the ips of this GetIps.

        Dedicated IP(s) available on your account  # noqa: E501

        :param ips: The ips of this GetIps.  # noqa: E501
        :type: list[GetIp]
        """
        if ips is None:
            raise ValueError("Invalid value for `ips`, must not be `None`")  # noqa: E501

        self._ips = ips

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GetIps):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    SendinBlue API

    SendinBlue provide a RESTFul API that can be used with any languages. With this API, you will be able to :   - Manage your campaigns and get the statistics   - Manage your contacts   - Send transactional Emails and SMS   - and much more...  You can download our wrappers at https://github.com/orgs/sendinblue  **Possible responses**   | Code | Message |   | :-------------: | ------------- |   | 200  | OK. Successful Request  |   | 201  | OK. Successful Creation |   | 202  | OK. Request accepted |   | 204  | OK. Successful Update/Deletion  |   | 400  | Error. Bad Request  |   | 401  | Error. Authentication Needed  |   | 402  | Error. Not enough credit, plan upgrade needed  |   | 403  | Error. Permission denied  |   | 404  | Error. Object does not exist |   | 405  | Error. Method not allowed  |   # noqa: E501

    OpenAPI spec version: 3.0.0
    Contact: contact@sendinblue.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class CreateSenderIps(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'ip': 'str',
        'domain': 'str',
        'weight': 'int'
    }

    attribute_map = {
        'ip': 'ip',
        'domain': 'domain',
        'weight': 'weight'
    }

    def __init__(self, ip=None, domain=None, weight=None):  # noqa: E501
        """CreateSenderIps - a model defined in Swagger"""  # noqa: E501

        self._ip = None
        self._domain = None
        self._weight = None
        self.discriminator = None

        self.ip = ip
        self.domain = domain
        if weight is not None:
            self.weight = weight

    @property
    def ip(self):
        """Gets the ip of this CreateSenderIps.  # noqa: E501

        Dedicated IP available in your account  # noqa: E501

        :return: The ip of this CreateSenderIps.  # noqa: E501
        :rtype: str
        """
        return self._ip

    @ip.setter
    def ip(self, ip):
        """Sets the ip of this CreateSenderIps.

        Dedicated IP available in your account  # noqa: E501

        :param ip: The ip of this CreateSenderIps.  # noqa: E501
        :type: str
        """
        if ip is None:
            raise ValueError("Invalid value for `ip`, must not be `None`")  # noqa: E501

        self._ip = ip

    @property
    def domain(self):
        """Gets the domain of this CreateSenderIps.  # noqa: E501

        Domain of the IP  # noqa: E501

        :return: The domain of this CreateSenderIps.  # noqa: E501
        :rtype: str
        """
        return self._domain

    @domain.setter
    def domain(self, domain):
        """Sets the domain of this CreateSenderIps.

        Domain of the IP  # noqa: E501

        :param domain: The domain of this CreateSenderIps.  # noqa: E501
        :type: str
        """
        if domain is None:
            raise ValueError("Invalid value for `domain`, must not be `None`")  # noqa: E501

        self._domain = domain

    @property
    def weight(self):
        """Gets the weight of this CreateSenderIps.  # noqa: E501

        Weight to apply to the IP. Sum of all IP weights must be 100. Should be passed for either ALL or NONE of the IPs. If it's not passed, the sending will be equally balanced on all IPs.  # noqa: E501

        :return: The weight of this CreateSenderIps.  # noqa: E501
        :rtype: int
        """
        return self._weight

    @weight.setter
    def weight(self, weight):
        """Sets the weight of this CreateSenderIps.

        Weight to apply to the IP. Sum of all IP weights must be 100. Should be passed for either ALL or NONE of the IPs. If it's not passed, the sending will be equally balanced on all IPs.  # noqa: E501

        :param weight: The weight of this CreateSenderIps.  # noqa: E501
        :type: int
        """
        if weight is not None and weight > 100:  # noqa: E501
            raise ValueError("Invalid value for `weight`, must be a value less than or equal to `100`")  # noqa: E501
        if weight is not None and weight < 1:  # noqa: E501
            raise ValueError("Invalid value for `weight`, must be a value greater than or equal to `1`")  # noqa: E501

        self._weight = weight

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateSenderIps):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    SendinBlue API

    SendinBlue provide a RESTFul API that can be used with any languages. With this API, you will be able to :   - Manage your campaigns and get the statistics   - Manage your contacts   - Send transactional Emails and SMS   - and much more...  You can download our wrappers at https://github.com/orgs/sendinblue  **Possible responses**   | Code | Message |   | :-------------: | ------------- |   | 200  | OK. Successful Request  |   | 201  | OK. Successful Creation |   | 202  | OK. Request accepted |   | 204  | OK. Successful Update/Deletion  |   | 400  | Error. Bad Request  |   | 401  | Error. Authentication Needed  |   | 402  | Error. Not enough credit, plan upgrade needed  |   | 403  | Error. Permission denied  |   | 404  | Error. Object does not exist |   | 405  | Error. Method not allowed  |   # noqa: E501

    OpenAPI spec version: 3.0.0
    Contact: contact@sendinblue.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import sib_api_v3_sdk
from sib_api_v3_sdk.models.send_smtp_email_reply_to import SendSmtpEmailReplyTo  # noqa: E501
from sib_api_v3_sdk.rest import ApiException


class TestSendSmtpEmailReplyTo(unittest.TestCase):
    """SendSmtpEmailReplyTo unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testSendSmtpEmailReplyTo(self):
        """Test SendSmtpEmailReplyTo"""
        # FIXME: construct object with mandatory attributes with example values
        # model = sib_api_v3_sdk.models.send_smtp_email_reply_to.SendSmtpEmailReplyTo()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    SendinBlue API

    SendinBlue provide a RESTFul API that can be used with any languages. With this API, you will be able to :   - Manage your campaigns and get the statistics   - Manage your contacts   - Send transactional Emails and SMS   - and much more...  You can download our wrappers at https://github.com/orgs/sendinblue  **Possible responses**   | Code | Message |   | :-------------: | ------------- |   | 200  | OK. Successful Request  |   | 201  | OK. Successful Creation |   | 202  | OK. Request accepted |   | 204  | OK. Successful Update/Deletion  |   | 400  | Error. Bad Request  |   | 401  | Error. Authentication Needed  |   | 402  | Error. Not enough credit, plan upgrade needed  |   | 403  | Error. Permission denied  |   | 404  | Error. Object does not exist |   | 405  | Error. Method not allowed  |   # noqa: E501

    OpenAPI spec version: 3.0.0
    Contact: contact@sendinblue.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from sib_api_v3_sdk.api_client import ApiClient


class ResellerApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def add_credits(self, child_auth_key, add_credits, **kwargs):  # noqa: E501
        """Add Email and/or SMS credits to a specific child account  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.add_credits(child_auth_key, add_credits, async=True)
        >>> result = thread.get()

        :param async bool
        :param str child_auth_key: auth key of reseller's child (required)
        :param AddCredits add_credits: Values to post to add credit to a specific child account (required)
        :return: RemainingCreditModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.add_credits_with_http_info(child_auth_key, add_credits, **kwargs)  # noqa: E501
        else:
            (data) = self.add_credits_with_http_info(child_auth_key, add_credits, **kwargs)  # noqa: E501
            return data

    def add_credits_with_http_info(self, child_auth_key, add_credits, **kwargs):  # noqa: E501
        """Add Email and/or SMS credits to a specific child account  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.add_credits_with_http_info(child_auth_key, add_credits, async=True)
        >>> result = thread.get()

        :param async bool
        :param str child_auth_key: auth key of reseller's child (required)
        :param AddCredits add_credits: Values to post to add credit to a specific child account (required)
        :return: RemainingCreditModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['child_auth_key', 'add_credits']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method add_credits" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'child_auth_key' is set
        if ('child_auth_key' not in params or
                params['child_auth_key'] is None):
            raise ValueError("Missing the required parameter `child_auth_key` when calling `add_credits`")  # noqa: E501
        # verify the required parameter 'add_credits' is set
        if ('add_credits' not in params or
                params['add_credits'] is None):
            raise ValueError("Missing the required parameter `add_credits` when calling `add_credits`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'child_auth_key' in params:
            path_params['childAuthKey'] = params['child_auth_key']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'add_credits' in params:
            body_params = params['add_credits']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api-key', 'partner-key']  # noqa: E501

        return self.api_client.call_api(
            '/reseller/children/{childAuthKey}/credits/add', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RemainingCreditModel',  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def associate_ip_to_child(self, child_auth_key, ip, **kwargs):  # noqa: E501
        """Associate a dedicated IP to the child  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.associate_ip_to_child(child_auth_key, ip, async=True)
        >>> result = thread.get()

        :param async bool
        :param str child_auth_key: auth key of reseller's child (required)
        :param ManageIp ip: IP to associate (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.associate_ip_to_child_with_http_info(child_auth_key, ip, **kwargs)  # noqa: E501
        else:
            (data) = self.associate_ip_to_child_with_http_info(child_auth_key, ip, **kwargs)  # noqa: E501
            return data

    def associate_ip_to_child_with_http_info(self, child_auth_key, ip, **kwargs):  # noqa: E501
        """Associate a dedicated IP to the child  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.associate_ip_to_child_with_http_info(child_auth_key, ip, async=True)
        >>> result = thread.get()

        :param async bool
        :param str child_auth_key: auth key of reseller's child (required)
        :param ManageIp ip: IP to associate (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['child_auth_key', 'ip']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method associate_ip_to_child" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'child_auth_key' is set
        if ('child_auth_key' not in params or
                params['child_auth_key'] is None):
            raise ValueError("Missing the required parameter `child_auth_key` when calling `associate_ip_to_child`")  # noqa: E501
        # verify the required parameter 'ip' is set
        if ('ip' not in params or
                params['ip'] is None):
            raise ValueError("Missing the required parameter `ip` when calling `associate_ip_to_child`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'child_auth_key' in params:
            path_params['childAuthKey'] = params['child_auth_key']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'ip' in params:
            body_params = params['ip']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api-key', 'partner-key']  # noqa: E501

        return self.api_client.call_api(
            '/reseller/children/{childAuthKey}/ips/associate', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_child_domain(self, child_auth_key, add_child_domain, **kwargs):  # noqa: E501
        """Creates a domain for a child account  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.create_child_domain(child_auth_key, add_child_domain, async=True)
        >>> result = thread.get()

        :param async bool
        :param str child_auth_key: auth key of reseller's child (required)
        :param AddChildDomain add_child_domain: Sender domain to add for a specific child account (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.create_child_domain_with_http_info(child_auth_key, add_child_domain, **kwargs)  # noqa: E501
        else:
            (data) = self.create_child_domain_with_http_info(child_auth_key, add_child_domain, **kwargs)  # noqa: E501
            return data

    def create_child_domain_with_http_info(self, child_auth_key, add_child_domain, **kwargs):  # noqa: E501
        """Creates a domain for a child account  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.create_child_domain_with_http_info(child_auth_key, add_child_domain, async=True)
        >>> result = thread.get()

        :param async bool
        :param str child_auth_key: auth key of reseller's child (required)
        :param AddChildDomain add_child_domain: Sender domain to add for a specific child account (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['child_auth_key', 'add_child_domain']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_child_domain" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'child_auth_key' is set
        if ('child_auth_key' not in params or
                params['child_auth_key'] is None):
            raise ValueError("Missing the required parameter `child_auth_key` when calling `create_child_domain`")  # noqa: E501
        # verify the required parameter 'add_child_domain' is set
        if ('add_child_domain' not in params or
                params['add_child_domain'] is None):
            raise ValueError("Missing the required parameter `add_child_domain` when calling `create_child_domain`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'child_auth_key' in params:
            path_params['childAuthKey'] = params['child_auth_key']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'add_child_domain' in params:
            body_params = params['add_child_domain']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api-key', 'partner-key']  # noqa: E501

        return self.api_client.call_api(
            '/reseller/children/{childAuthKey}/domains', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_reseller_child(self, **kwargs):  # noqa: E501
        """Creates a reseller child  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.create_reseller_child(async=True)
        >>> result = thread.get()

        :param async bool
        :param CreateChild reseller_child: reseller child to add
        :return: CreateReseller
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.create_reseller_child_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.create_reseller_child_with_http_info(**kwargs)  # noqa: E501
            return data

    def create_reseller_child_with_http_info(self, **kwargs):  # noqa: E501
        """Creates a reseller child  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.create_reseller_child_with_http_info(async=True)
        >>> result = thread.get()

        :param async bool
        :param CreateChild reseller_child: reseller child to add
        :return: CreateReseller
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['reseller_child']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_reseller_child" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'reseller_child' in params:
            body_params = params['reseller_child']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api-key', 'partner-key']  # noqa: E501

        return self.api_client.call_api(
            '/reseller/children', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CreateReseller',  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_child_domain(self, child_auth_key, domain_name, **kwargs):  # noqa: E501
        """Deletes the sender domain of the reseller child based on the childAuthKey and domainName passed  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.delete_child_domain(child_auth_key, domain_name, async=True)
        >>> result = thread.get()

        :param async bool
        :param str child_auth_key: auth key of reseller's child (required)
        :param str domain_name: Pass the existing domain that needs to be deleted (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.delete_child_domain_with_http_info(child_auth_key, domain_name, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_child_domain_with_http_info(child_auth_key, domain_name, **kwargs)  # noqa: E501
            return data

    def delete_child_domain_with_http_info(self, child_auth_key, domain_name, **kwargs):  # noqa: E501
        """Deletes the sender domain of the reseller child based on the childAuthKey and domainName passed  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.delete_child_domain_with_http_info(child_auth_key, domain_name, async=True)
        >>> result = thread.get()

        :param async bool
        :param str child_auth_key: auth key of reseller's child (required)
        :param str domain_name: Pass the existing domain that needs to be deleted (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['child_auth_key', 'domain_name']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_child_domain" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'child_auth_key' is set
        if ('child_auth_key' not in params or
                params['child_auth_key'] is None):
            raise ValueError("Missing the required parameter `child_auth_key` when calling `delete_child_domain`")  # noqa: E501
        # verify the required parameter 'domain_name' is set
        if ('domain_name' not in params or
                params['domain_name'] is None):
            raise ValueError("Missing the required parameter `domain_name` when calling `delete_child_domain`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'child_auth_key' in params:
            path_params['childAuthKey'] = params['child_auth_key']  # noqa: E501
        if 'domain_name' in params:
            path_params['domainName'] = params['domain_name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api-key', 'partner-key']  # noqa: E501

        return self.api_client.call_api(
            '/reseller/children/{childAuthKey}/domains/{domainName}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_reseller_child(self, child_auth_key, **kwargs):  # noqa: E501
        """Deletes a single reseller child based on the childAuthKey supplied  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.delete_reseller_child(child_auth_key, async=True)
        >>> result = thread.get()

        :param async bool
        :param str child_auth_key: auth key of reseller's child (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.delete_reseller_child_with_http_info(child_auth_key, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_reseller_child_with_http_info(child_auth_key, **kwargs)  # noqa: E501
            return data

    def delete_reseller_child_with_http_info(self, child_auth_key, **kwargs):  # noqa: E501
        """Deletes a single reseller child based on the childAuthKey supplied  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.delete_reseller_child_with_http_info(child_auth_key, async=True)
        >>> result = thread.get()

        :param async bool
        :param str child_auth_key: auth key of reseller's child (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['child_auth_key']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_reseller_child" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'child_auth_key' is set
        if ('child_auth_key' not in params or
                params['child_auth_key'] is None):
            raise ValueError("Missing the required parameter `child_auth_key` when calling `delete_reseller_child`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'child_auth_key' in params:
            path_params['childAuthKey'] = params['child_auth_key']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api-key', 'partner-key']  # noqa: E501

        return self.api_client.call_api(
            '/reseller/children/{childAuthKey}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def dissociate_ip_from_child(self, child_auth_key, ip, **kwargs):  # noqa: E501
        """Dissociate a dedicated IP to the child  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.dissociate_ip_from_child(child_auth_key, ip, async=True)
        >>> result = thread.get()

        :param async bool
        :param str child_auth_key: auth key of reseller's child (required)
        :param ManageIp ip: IP to dissociate (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.dissociate_ip_from_child_with_http_info(child_auth_key, ip, **kwargs)  # noqa: E501
        else:
            (data) = self.dissociate_ip_from_child_with_http_info(child_auth_key, ip, **kwargs)  # noqa: E501
            return data

    def dissociate_ip_from_child_with_http_info(self, child_auth_key, ip, **kwargs):  # noqa: E501
        """Dissociate a dedicated IP to the child  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.dissociate_ip_from_child_with_http_info(child_auth_key, ip, async=True)
        >>> result = thread.get()

        :param async bool
        :param str child_auth_key: auth key of reseller's child (required)
        :param ManageIp ip: IP to dissociate (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['child_auth_key', 'ip']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method dissociate_ip_from_child" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'child_auth_key' is set
        if ('child_auth_key' not in params or
                params['child_auth_key'] is None):
            raise ValueError("Missing the required parameter `child_auth_key` when calling `dissociate_ip_from_child`")  # noqa: E501
        # verify the required parameter 'ip' is set
        if ('ip' not in params or
                params['ip'] is None):
            raise ValueError("Missing the required parameter `ip` when calling `dissociate_ip_from_child`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'child_auth_key' in params:
            path_params['childAuthKey'] = params['child_auth_key']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'ip' in params:
            body_params = params['ip']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api-key', 'partner-key']  # noqa: E501

        return self.api_client.call_api(
            '/reseller/children/{childAuthKey}/ips/dissociate', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_child_domains(self, child_auth_key, **kwargs):  # noqa: E501
        """Gets all the sender domains of a specific child account  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_child_domains(child_auth_key, async=True)
        >>> result = thread.get()

        :param async bool
        :param str child_auth_key: auth key of reseller's child (required)
        :return: GetChildDomains
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.get_child_domains_with_http_info(child_auth_key, **kwargs)  # noqa: E501
        else:
            (data) = self.get_child_domains_with_http_info(child_auth_key, **kwargs)  # noqa: E501
            return data

    def get_child_domains_with_http_info(self, child_auth_key, **kwargs):  # noqa: E501
        """Gets all the sender domains of a specific child account  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_child_domains_with_http_info(child_auth_key, async=True)
        >>> result = thread.get()

        :param async bool
        :param str child_auth_key: auth key of reseller's child (required)
        :return: GetChildDomains
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['child_auth_key']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_child_domains" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'child_auth_key' is set
        if ('child_auth_key' not in params or
                params['child_auth_key'] is None):
            raise ValueError("Missing the required parameter `child_auth_key` when calling `get_child_domains`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'child_auth_key' in params:
            path_params['childAuthKey'] = params['child_auth_key']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api-key', 'partner-key']  # noqa: E501

        return self.api_client.call_api(
            '/reseller/children/{childAuthKey}/domains', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GetChildDomains',  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_child_info(self, child_auth_key, **kwargs):  # noqa: E501
        """Gets the info about a specific child account  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_child_info(child_auth_key, async=True)
        >>> result = thread.get()

        :param async bool
        :param str child_auth_key: auth key of reseller's child (required)
        :return: GetChildInfo
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.get_child_info_with_http_info(child_auth_key, **kwargs)  # noqa: E501
        else:
            (data) = self.get_child_info_with_http_info(child_auth_key, **kwargs)  # noqa: E501
            return data

    def get_child_info_with_http_info(self, child_auth_key, **kwargs):  # noqa: E501
        """Gets the info about a specific child account  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_child_info_with_http_info(child_auth_key, async=True)
        >>> result = thread.get()

        :param async bool
        :param str child_auth_key: auth key of reseller's child (required)
        :return: GetChildInfo
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['child_auth_key']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_child_info" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'child_auth_key' is set
        if ('child_auth_key' not in params or
                params['child_auth_key'] is None):
            raise ValueError("Missing the required parameter `child_auth_key` when calling `get_child_info`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'child_auth_key' in params:
            path_params['childAuthKey'] = params['child_auth_key']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api-key', 'partner-key']  # noqa: E501

        return self.api_client.call_api(
            '/reseller/children/{childAuthKey}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GetChildInfo',  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_reseller_childs(self, **kwargs):  # noqa: E501
        """Gets the list of all reseller&#39;s children accounts  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_reseller_childs(async=True)
        >>> result = thread.get()

        :param async bool
        :return: GetChildrenList
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.get_reseller_childs_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_reseller_childs_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_reseller_childs_with_http_info(self, **kwargs):  # noqa: E501
        """Gets the list of all reseller&#39;s children accounts  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_reseller_childs_with_http_info(async=True)
        >>> result = thread.get()

        :param async bool
        :return: GetChildrenList
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_reseller_childs" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api-key', 'partner-key']  # noqa: E501

        return self.api_client.call_api(
            '/reseller/children', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GetChildrenList',  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_sso_token(self, child_auth_key, **kwargs):  # noqa: E501
        """Get session token to access Sendinblue (SSO)  # noqa: E501

        It returns a session [token] which will remain valid for a short period of time. A child account will be able to access a white-labeled section by using the following url pattern => https:/email.mydomain.com/login/sso?token=[token]  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_sso_token(child_auth_key, async=True)
        >>> result = thread.get()

        :param async bool
        :param str child_auth_key: auth key of reseller's child (required)
        :return: GetSsoToken
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.get_sso_token_with_http_info(child_auth_key, **kwargs)  # noqa: E501
        else:
            (data) = self.get_sso_token_with_http_info(child_auth_key, **kwargs)  # noqa: E501
            return data

    def get_sso_token_with_http_info(self, child_auth_key, **kwargs):  # noqa: E501
        """Get session token to access Sendinblue (SSO)  # noqa: E501

        It returns a session [token] which will remain valid for a short period of time. A child account will be able to access a white-labeled section by using the following url pattern => https:/email.mydomain.com/login/sso?token=[token]  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_sso_token_with_http_info(child_auth_key, async=True)
        >>> result = thread.get()

        :param async bool
        :param str child_auth_key: auth key of reseller's child (required)
        :return: GetSsoToken
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['child_auth_key']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_sso_token" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'child_auth_key' is set
        if ('child_auth_key' not in params or
                params['child_auth_key'] is None):
            raise ValueError("Missing the required parameter `child_auth_key` when calling `get_sso_token`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'child_auth_key' in params:
            path_params['childAuthKey'] = params['child_auth_key']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api-key', 'partner-key']  # noqa: E501

        return self.api_client.call_api(
            '/reseller/children/{childAuthKey}/auth', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GetSsoToken',  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def remove_credits(self, child_auth_key, remove_credits, **kwargs):  # noqa: E501
        """Remove Email and/or SMS credits from a specific child account  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.remove_credits(child_auth_key, remove_credits, async=True)
        >>> result = thread.get()

        :param async bool
        :param str child_auth_key: auth key of reseller's child (required)
        :param RemoveCredits remove_credits: Values to post to remove email or SMS credits from a specific child account (required)
        :return: RemainingCreditModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.remove_credits_with_http_info(child_auth_key, remove_credits, **kwargs)  # noqa: E501
        else:
            (data) = self.remove_credits_with_http_info(child_auth_key, remove_credits, **kwargs)  # noqa: E501
            return data

    def remove_credits_with_http_info(self, child_auth_key, remove_credits, **kwargs):  # noqa: E501
        """Remove Email and/or SMS credits from a specific child account  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.remove_credits_with_http_info(child_auth_key, remove_credits, async=True)
        >>> result = thread.get()

        :param async bool
        :param str child_auth_key: auth key of reseller's child (required)
        :param RemoveCredits remove_credits: Values to post to remove email or SMS credits from a specific child account (required)
        :return: RemainingCreditModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['child_auth_key', 'remove_credits']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method remove_credits" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'child_auth_key' is set
        if ('child_auth_key' not in params or
                params['child_auth_key'] is None):
            raise ValueError("Missing the required parameter `child_auth_key` when calling `remove_credits`")  # noqa: E501
        # verify the required parameter 'remove_credits' is set
        if ('remove_credits' not in params or
                params['remove_credits'] is None):
            raise ValueError("Missing the required parameter `remove_credits` when calling `remove_credits`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'child_auth_key' in params:
            path_params['childAuthKey'] = params['child_auth_key']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'remove_credits' in params:
            body_params = params['remove_credits']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api-key', 'partner-key']  # noqa: E501

        return self.api_client.call_api(
            '/reseller/children/{childAuthKey}/credits/remove', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RemainingCreditModel',  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_child_account_status(self, child_auth_key, update_child_account_status, **kwargs):  # noqa: E501
        """Updates infos of reseller&#39;s child account status based on the childAuthKey supplied  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.update_child_account_status(child_auth_key, update_child_account_status, async=True)
        >>> result = thread.get()

        :param async bool
        :param str child_auth_key: auth key of reseller's child (required)
        :param UpdateChildAccountStatus update_child_account_status: values to update in child account status (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.update_child_account_status_with_http_info(child_auth_key, update_child_account_status, **kwargs)  # noqa: E501
        else:
            (data) = self.update_child_account_status_with_http_info(child_auth_key, update_child_account_status, **kwargs)  # noqa: E501
            return data

    def update_child_account_status_with_http_info(self, child_auth_key, update_child_account_status, **kwargs):  # noqa: E501
        """Updates infos of reseller&#39;s child account status based on the childAuthKey supplied  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.update_child_account_status_with_http_info(child_auth_key, update_child_account_status, async=True)
        >>> result = thread.get()

        :param async bool
        :param str child_auth_key: auth key of reseller's child (required)
        :param UpdateChildAccountStatus update_child_account_status: values to update in child account status (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['child_auth_key', 'update_child_account_status']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_child_account_status" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'child_auth_key' is set
        if ('child_auth_key' not in params or
                params['child_auth_key'] is None):
            raise ValueError("Missing the required parameter `child_auth_key` when calling `update_child_account_status`")  # noqa: E501
        # verify the required parameter 'update_child_account_status' is set
        if ('update_child_account_status' not in params or
                params['update_child_account_status'] is None):
            raise ValueError("Missing the required parameter `update_child_account_status` when calling `update_child_account_status`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'child_auth_key' in params:
            path_params['childAuthKey'] = params['child_auth_key']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'update_child_account_status' in params:
            body_params = params['update_child_account_status']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api-key', 'partner-key']  # noqa: E501

        return self.api_client.call_api(
            '/reseller/children/{childAuthKey}/accountStatus', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_child_domain(self, child_auth_key, domain_name, update_child_domain, **kwargs):  # noqa: E501
        """Updates the sender domain of reseller&#39;s child based on the childAuthKey and domainName passed  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.update_child_domain(child_auth_key, domain_name, update_child_domain, async=True)
        >>> result = thread.get()

        :param async bool
        :param str child_auth_key: auth key of reseller's child (required)
        :param str domain_name: Pass the existing domain that needs to be updated (required)
        :param UpdateChildDomain update_child_domain: value to update for sender domain (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.update_child_domain_with_http_info(child_auth_key, domain_name, update_child_domain, **kwargs)  # noqa: E501
        else:
            (data) = self.update_child_domain_with_http_info(child_auth_key, domain_name, update_child_domain, **kwargs)  # noqa: E501
            return data

    def update_child_domain_with_http_info(self, child_auth_key, domain_name, update_child_domain, **kwargs):  # noqa: E501
        """Updates the sender domain of reseller&#39;s child based on the childAuthKey and domainName passed  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.update_child_domain_with_http_info(child_auth_key, domain_name, update_child_domain, async=True)
        >>> result = thread.get()

        :param async bool
        :param str child_auth_key: auth key of reseller's child (required)
        :param str domain_name: Pass the existing domain that needs to be updated (required)
        :param UpdateChildDomain update_child_domain: value to update for sender domain (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['child_auth_key', 'domain_name', 'update_child_domain']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_child_domain" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'child_auth_key' is set
        if ('child_auth_key' not in params or
                params['child_auth_key'] is None):
            raise ValueError("Missing the required parameter `child_auth_key` when calling `update_child_domain`")  # noqa: E501
        # verify the required parameter 'domain_name' is set
        if ('domain_name' not in params or
                params['domain_name'] is None):
            raise ValueError("Missing the required parameter `domain_name` when calling `update_child_domain`")  # noqa: E501
        # verify the required parameter 'update_child_domain' is set
        if ('update_child_domain' not in params or
                params['update_child_domain'] is None):
            raise ValueError("Missing the required parameter `update_child_domain` when calling `update_child_domain`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'child_auth_key' in params:
            path_params['childAuthKey'] = params['child_auth_key']  # noqa: E501
        if 'domain_name' in params:
            path_params['domainName'] = params['domain_name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'update_child_domain' in params:
            body_params = params['update_child_domain']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api-key', 'partner-key']  # noqa: E501

        return self.api_client.call_api(
            '/reseller/children/{childAuthKey}/domains/{domainName}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_reseller_child(self, child_auth_key, reseller_child, **kwargs):  # noqa: E501
        """Updates infos of reseller&#39;s child based on the childAuthKey supplied  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.update_reseller_child(child_auth_key, reseller_child, async=True)
        >>> result = thread.get()

        :param async bool
        :param str child_auth_key: auth key of reseller's child (required)
        :param UpdateChild reseller_child: values to update in child profile (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.update_reseller_child_with_http_info(child_auth_key, reseller_child, **kwargs)  # noqa: E501
        else:
            (data) = self.update_reseller_child_with_http_info(child_auth_key, reseller_child, **kwargs)  # noqa: E501
            return data

    def update_reseller_child_with_http_info(self, child_auth_key, reseller_child, **kwargs):  # noqa: E501
        """Updates infos of reseller&#39;s child based on the childAuthKey supplied  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.update_reseller_child_with_http_info(child_auth_key, reseller_child, async=True)
        >>> result = thread.get()

        :param async bool
        :param str child_auth_key: auth key of reseller's child (required)
        :param UpdateChild reseller_child: values to update in child profile (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['child_auth_key', 'reseller_child']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_reseller_child" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'child_auth_key' is set
        if ('child_auth_key' not in params or
                params['child_auth_key'] is None):
            raise ValueError("Missing the required parameter `child_auth_key` when calling `update_reseller_child`")  # noqa: E501
        # verify the required parameter 'reseller_child' is set
        if ('reseller_child' not in params or
                params['reseller_child'] is None):
            raise ValueError("Missing the required parameter `reseller_child` when calling `update_reseller_child`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'child_auth_key' in params:
            path_params['childAuthKey'] = params['child_auth_key']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'reseller_child' in params:
            body_params = params['reseller_child']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api-key', 'partner-key']  # noqa: E501

        return self.api_client.call_api(
            '/reseller/children/{childAuthKey}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    SendinBlue API

    SendinBlue provide a RESTFul API that can be used with any languages. With this API, you will be able to :   - Manage your campaigns and get the statistics   - Manage your contacts   - Send transactional Emails and SMS   - and much more...  You can download our wrappers at https://github.com/orgs/sendinblue  **Possible responses**   | Code | Message |   | :-------------: | ------------- |   | 200  | OK. Successful Request  |   | 201  | OK. Successful Creation |   | 202  | OK. Request accepted |   | 204  | OK. Successful Update/Deletion  |   | 400  | Error. Bad Request  |   | 401  | Error. Authentication Needed  |   | 402  | Error. Not enough credit, plan upgrade needed  |   | 403  | Error. Permission denied  |   | 404  | Error. Object does not exist |   | 405  | Error. Method not allowed  |   # noqa: E501

    OpenAPI spec version: 3.0.0
    Contact: contact@sendinblue.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class GetCampaignStats(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'list_id': 'int',
        'unique_clicks': 'int',
        'clickers': 'int',
        'complaints': 'int',
        'delivered': 'int',
        'sent': 'int',
        'soft_bounces': 'int',
        'hard_bounces': 'int',
        'unique_views': 'int',
        'unsubscriptions': 'int',
        'viewed': 'int',
        'deferred': 'int'
    }

    attribute_map = {
        'list_id': 'listId',
        'unique_clicks': 'uniqueClicks',
        'clickers': 'clickers',
        'complaints': 'complaints',
        'delivered': 'delivered',
        'sent': 'sent',
        'soft_bounces': 'softBounces',
        'hard_bounces': 'hardBounces',
        'unique_views': 'uniqueViews',
        'unsubscriptions': 'unsubscriptions',
        'viewed': 'viewed',
        'deferred': 'deferred'
    }

    def __init__(self, list_id=None, unique_clicks=None, clickers=None, complaints=None, delivered=None, sent=None, soft_bounces=None, hard_bounces=None, unique_views=None, unsubscriptions=None, viewed=None, deferred=None):  # noqa: E501
        """GetCampaignStats - a model defined in Swagger"""  # noqa: E501

        self._list_id = None
        self._unique_clicks = None
        self._clickers = None
        self._complaints = None
        self._delivered = None
        self._sent = None
        self._soft_bounces = None
        self._hard_bounces = None
        self._unique_views = None
        self._unsubscriptions = None
        self._viewed = None
        self._deferred = None
        self.discriminator = None

        if list_id is not None:
            self.list_id = list_id
        self.unique_clicks = unique_clicks
        self.clickers = clickers
        self.complaints = complaints
        self.delivered = delivered
        self.sent = sent
        self.soft_bounces = soft_bounces
        self.hard_bounces = hard_bounces
        self.unique_views = unique_views
        self.unsubscriptions = unsubscriptions
        self.viewed = viewed
        if deferred is not None:
            self.deferred = deferred

    @property
    def list_id(self):
        """Gets the list_id of this GetCampaignStats.  # noqa: E501

        List Id of email campaign (only in case of get email campaign(s)(not for global stats))  # noqa: E501

        :return: The list_id of this GetCampaignStats.  # noqa: E501
        :rtype: int
        """
        return self._list_id

    @list_id.setter
    def list_id(self, list_id):
        """Sets the list_id of this GetCampaignStats.

        List Id of email campaign (only in case of get email campaign(s)(not for global stats))  # noqa: E501

        :param list_id: The list_id of this GetCampaignStats.  # noqa: E501
        :type: int
        """

        self._list_id = list_id

    @property
    def unique_clicks(self):
        """Gets the unique_clicks of this GetCampaignStats.  # noqa: E501

        Number of unique clicks for the campaign  # noqa: E501

        :return: The unique_clicks of this GetCampaignStats.  # noqa: E501
        :rtype: int
        """
        return self._unique_clicks

    @unique_clicks.setter
    def unique_clicks(self, unique_clicks):
        """Sets the unique_clicks of this GetCampaignStats.

        Number of unique clicks for the campaign  # noqa: E501

        :param unique_clicks: The unique_clicks of this GetCampaignStats.  # noqa: E501
        :type: int
        """
        if unique_clicks is None:
            raise ValueError("Invalid value for `unique_clicks`, must not be `None`")  # noqa: E501

        self._unique_clicks = unique_clicks

    @property
    def clickers(self):
        """Gets the clickers of this GetCampaignStats.  # noqa: E501

        Number of total clicks for the campaign  # noqa: E501

        :return: The clickers of this GetCampaignStats.  # noqa: E501
        :rtype: int
        """
        return self._clickers

    @clickers.setter
    def clickers(self, clickers):
        """Sets the clickers of this GetCampaignStats.

        Number of total clicks for the campaign  # noqa: E501

        :param clickers: The clickers of this GetCampaignStats.  # noqa: E501
        :type: int
        """
        if clickers is None:
            raise ValueError("Invalid value for `clickers`, must not be `None`")  # noqa: E501

        self._clickers = clickers

    @property
    def complaints(self):
        """Gets the complaints of this GetCampaignStats.  # noqa: E501

        Number of complaints (Spam reports) for the campaign  # noqa: E501

        :return: The complaints of this GetCampaignStats.  # noqa: E501
        :rtype: int
        """
        return self._complaints

    @complaints.setter
    def complaints(self, complaints):
        """Sets the complaints of this GetCampaignStats.

        Number of complaints (Spam reports) for the campaign  # noqa: E501

        :param complaints: The complaints of this GetCampaignStats.  # noqa: E501
        :type: int
        """
        if complaints is None:
            raise ValueError("Invalid value for `complaints`, must not be `None`")  # noqa: E501

        self._complaints = complaints

    @property
    def delivered(self):
        """Gets the delivered of this GetCampaignStats.  # noqa: E501

        Number of delivered emails for the campaign  # noqa: E501

        :return: The delivered of this GetCampaignStats.  # noqa: E501
        :rtype: int
        """
        return self._delivered

    @delivered.setter
    def delivered(self, delivered):
        """Sets the delivered of this GetCampaignStats.

        Number of delivered emails for the campaign  # noqa: E501

        :param delivered: The delivered of this GetCampaignStats.  # noqa: E501
        :type: int
        """
        if delivered is None:
            raise ValueError("Invalid value for `delivered`, must not be `None`")  # noqa: E501

        self._delivered = delivered

    @property
    def sent(self):
        """Gets the sent of this GetCampaignStats.  # noqa: E501

        Number of sent emails for the campaign  # noqa: E501

        :return: The sent of this GetCampaignStats.  # noqa: E501
        :rtype: int
        """
        return self._sent

    @sent.setter
    def sent(self, sent):
        """Sets the sent of this GetCampaignStats.

        Number of sent emails for the campaign  # noqa: E501

        :param sent: The sent of this GetCampaignStats.  # noqa: E501
        :type: int
        """
        if sent is None:
            raise ValueError("Invalid value for `sent`, must not be `None`")  # noqa: E501

        self._sent = sent

    @property
    def soft_bounces(self):
        """Gets the soft_bounces of this GetCampaignStats.  # noqa: E501

        Number of softbounce for the campaign  # noqa: E501

        :return: The soft_bounces of this GetCampaignStats.  # noqa: E501
        :rtype: int
        """
        return self._soft_bounces

    @soft_bounces.setter
    def soft_bounces(self, soft_bounces):
        """Sets the soft_bounces of this GetCampaignStats.

        Number of softbounce for the campaign  # noqa: E501

        :param soft_bounces: The soft_bounces of this GetCampaignStats.  # noqa: E501
        :type: int
        """
        if soft_bounces is None:
            raise ValueError("Invalid value for `soft_bounces`, must not be `None`")  # noqa: E501

        self._soft_bounces = soft_bounces

    @property
    def hard_bounces(self):
        """Gets the hard_bounces of this GetCampaignStats.  # noqa: E501

        Number of harbounce for the campaign  # noqa: E501

        :return: The hard_bounces of this GetCampaignStats.  # noqa: E501
        :rtype: int
        """
        return self._hard_bounces

    @hard_bounces.setter
    def hard_bounces(self, hard_bounces):
        """Sets the hard_bounces of this GetCampaignStats.

        Number of harbounce for the campaign  # noqa: E501

        :param hard_bounces: The hard_bounces of this GetCampaignStats.  # noqa: E501
        :type: int
        """
        if hard_bounces is None:
            raise ValueError("Invalid value for `hard_bounces`, must not be `None`")  # noqa: E501

        self._hard_bounces = hard_bounces

    @property
    def unique_views(self):
        """Gets the unique_views of this GetCampaignStats.  # noqa: E501

        Number of unique openings for the campaign  # noqa: E501

        :return: The unique_views of this GetCampaignStats.  # noqa: E501
        :rtype: int
        """
        return self._unique_views

    @unique_views.setter
    def unique_views(self, unique_views):
        """Sets the unique_views of this GetCampaignStats.

        Number of unique openings for the campaign  # noqa: E501

        :param unique_views: The unique_views of this GetCampaignStats.  # noqa: E501
        :type: int
        """
        if unique_views is None:
            raise ValueError("Invalid value for `unique_views`, must not be `None`")  # noqa: E501

        self._unique_views = unique_views

    @property
    def unsubscriptions(self):
        """Gets the unsubscriptions of this GetCampaignStats.  # noqa: E501

        Number of unsubscription for the campaign  # noqa: E501

        :return: The unsubscriptions of this GetCampaignStats.  # noqa: E501
        :rtype: int
        """
        return self._unsubscriptions

    @unsubscriptions.setter
    def unsubscriptions(self, unsubscriptions):
        """Sets the unsubscriptions of this GetCampaignStats.

        Number of unsubscription for the campaign  # noqa: E501

        :param unsubscriptions: The unsubscriptions of this GetCampaignStats.  # noqa: E501
        :type: int
        """
        if unsubscriptions is None:
            raise ValueError("Invalid value for `unsubscriptions`, must not be `None`")  # noqa: E501

        self._unsubscriptions = unsubscriptions

    @property
    def viewed(self):
        """Gets the viewed of this GetCampaignStats.  # noqa: E501

        Number of openings for the campaign  # noqa: E501

        :return: The viewed of this GetCampaignStats.  # noqa: E501
        :rtype: int
        """
        return self._viewed

    @viewed.setter
    def viewed(self, viewed):
        """Sets the viewed of this GetCampaignStats.

        Number of openings for the campaign  # noqa: E501

        :param viewed: The viewed of this GetCampaignStats.  # noqa: E501
        :type: int
        """
        if viewed is None:
            raise ValueError("Invalid value for `viewed`, must not be `None`")  # noqa: E501

        self._viewed = viewed

    @property
    def deferred(self):
        """Gets the deferred of this GetCampaignStats.  # noqa: E501

        Number of deferred emails for the campaign  # noqa: E501

        :return: The deferred of this GetCampaignStats.  # noqa: E501
        :rtype: int
        """
        return self._deferred

    @deferred.setter
    def deferred(self, deferred):
        """Sets the deferred of this GetCampaignStats.

        Number of deferred emails for the campaign  # noqa: E501

        :param deferred: The deferred of this GetCampaignStats.  # noqa: E501
        :type: int
        """

        self._deferred = deferred

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GetCampaignStats):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    SendinBlue API

    SendinBlue provide a RESTFul API that can be used with any languages. With this API, you will be able to :   - Manage your campaigns and get the statistics   - Manage your contacts   - Send transactional Emails and SMS   - and much more...  You can download our wrappers at https://github.com/orgs/sendinblue  **Possible responses**   | Code | Message |   | :-------------: | ------------- |   | 200  | OK. Successful Request  |   | 201  | OK. Successful Creation |   | 202  | OK. Request accepted |   | 204  | OK. Successful Update/Deletion  |   | 400  | Error. Bad Request  |   | 401  | Error. Authentication Needed  |   | 402  | Error. Not enough credit, plan upgrade needed  |   | 403  | Error. Permission denied  |   | 404  | Error. Object does not exist |   | 405  | Error. Method not allowed  |   # noqa: E501

    OpenAPI spec version: 3.0.0
    Contact: contact@sendinblue.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class SendSmtpEmailAttachment(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'url': 'str',
        'content': 'str',
        'name': 'str'
    }

    attribute_map = {
        'url': 'url',
        'content': 'content',
        'name': 'name'
    }

    def __init__(self, url=None, content=None, name=None):  # noqa: E501
        """SendSmtpEmailAttachment - a model defined in Swagger"""  # noqa: E501

        self._url = None
        self._content = None
        self._name = None
        self.discriminator = None

        if url is not None:
            self.url = url
        if content is not None:
            self.content = content
        if name is not None:
            self.name = name

    @property
    def url(self):
        """Gets the url of this SendSmtpEmailAttachment.  # noqa: E501

        Absolute url of the attachment (no local file).  # noqa: E501

        :return: The url of this SendSmtpEmailAttachment.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this SendSmtpEmailAttachment.

        Absolute url of the attachment (no local file).  # noqa: E501

        :param url: The url of this SendSmtpEmailAttachment.  # noqa: E501
        :type: str
        """

        self._url = url

    @property
    def content(self):
        """Gets the content of this SendSmtpEmailAttachment.  # noqa: E501

        Base64 encoded chunk data of the attachment generated on the fly  # noqa: E501

        :return: The content of this SendSmtpEmailAttachment.  # noqa: E501
        :rtype: str
        """
        return self._content

    @content.setter
    def content(self, content):
        """Sets the content of this SendSmtpEmailAttachment.

        Base64 encoded chunk data of the attachment generated on the fly  # noqa: E501

        :param content: The content of this SendSmtpEmailAttachment.  # noqa: E501
        :type: str
        """
        if content is not None and not re.search('^(?:[A-Za-z0-9+\/]{4})*(?:[A-Za-z0-9+\/]{2}==|[A-Za-z0-9+\/]{3}=)?$', content):  # noqa: E501
            raise ValueError("Invalid value for `content`, must be a follow pattern or equal to `/^(?:[A-Za-z0-9+\/]{4})*(?:[A-Za-z0-9+\/]{2}==|[A-Za-z0-9+\/]{3}=)?$/`")  # noqa: E501

        self._content = content

    @property
    def name(self):
        """Gets the name of this SendSmtpEmailAttachment.  # noqa: E501

        Required if content is passed. Name of the attachment  # noqa: E501

        :return: The name of this SendSmtpEmailAttachment.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this SendSmtpEmailAttachment.

        Required if content is passed. Name of the attachment  # noqa: E501

        :param name: The name of this SendSmtpEmailAttachment.  # noqa: E501
        :type: str
        """

        self._name = name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SendSmtpEmailAttachment):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    SendinBlue API

    SendinBlue provide a RESTFul API that can be used with any languages. With this API, you will be able to :   - Manage your campaigns and get the statistics   - Manage your contacts   - Send transactional Emails and SMS   - and much more...  You can download our wrappers at https://github.com/orgs/sendinblue  **Possible responses**   | Code | Message |   | :-------------: | ------------- |   | 200  | OK. Successful Request  |   | 201  | OK. Successful Creation |   | 202  | OK. Request accepted |   | 204  | OK. Successful Update/Deletion  |   | 400  | Error. Bad Request  |   | 401  | Error. Authentication Needed  |   | 402  | Error. Not enough credit, plan upgrade needed  |   | 403  | Error. Permission denied  |   | 404  | Error. Object does not exist |   | 405  | Error. Method not allowed  |   # noqa: E501

    OpenAPI spec version: 3.0.0
    Contact: contact@sendinblue.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class GetIp(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'ip': 'str',
        'active': 'bool',
        'domain': 'str'
    }

    attribute_map = {
        'id': 'id',
        'ip': 'ip',
        'active': 'active',
        'domain': 'domain'
    }

    def __init__(self, id=None, ip=None, active=None, domain=None):  # noqa: E501
        """GetIp - a model defined in Swagger"""  # noqa: E501

        self._id = None
        self._ip = None
        self._active = None
        self._domain = None
        self.discriminator = None

        self.id = id
        self.ip = ip
        self.active = active
        self.domain = domain

    @property
    def id(self):
        """Gets the id of this GetIp.  # noqa: E501

        ID of the dedicated IP  # noqa: E501

        :return: The id of this GetIp.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this GetIp.

        ID of the dedicated IP  # noqa: E501

        :param id: The id of this GetIp.  # noqa: E501
        :type: int
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def ip(self):
        """Gets the ip of this GetIp.  # noqa: E501

        Dedicated IP  # noqa: E501

        :return: The ip of this GetIp.  # noqa: E501
        :rtype: str
        """
        return self._ip

    @ip.setter
    def ip(self, ip):
        """Sets the ip of this GetIp.

        Dedicated IP  # noqa: E501

        :param ip: The ip of this GetIp.  # noqa: E501
        :type: str
        """
        if ip is None:
            raise ValueError("Invalid value for `ip`, must not be `None`")  # noqa: E501

        self._ip = ip

    @property
    def active(self):
        """Gets the active of this GetIp.  # noqa: E501

        Status of the IP (true=active, false=inactive)  # noqa: E501

        :return: The active of this GetIp.  # noqa: E501
        :rtype: bool
        """
        return self._active

    @active.setter
    def active(self, active):
        """Sets the active of this GetIp.

        Status of the IP (true=active, false=inactive)  # noqa: E501

        :param active: The active of this GetIp.  # noqa: E501
        :type: bool
        """
        if active is None:
            raise ValueError("Invalid value for `active`, must not be `None`")  # noqa: E501

        self._active = active

    @property
    def domain(self):
        """Gets the domain of this GetIp.  # noqa: E501

        Domain associated to the IP  # noqa: E501

        :return: The domain of this GetIp.  # noqa: E501
        :rtype: str
        """
        return self._domain

    @domain.setter
    def domain(self, domain):
        """Sets the domain of this GetIp.

        Domain associated to the IP  # noqa: E501

        :param domain: The domain of this GetIp.  # noqa: E501
        :type: str
        """
        if domain is None:
            raise ValueError("Invalid value for `domain`, must not be `None`")  # noqa: E501

        self._domain = domain

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GetIp):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    SendinBlue API

    SendinBlue provide a RESTFul API that can be used with any languages. With this API, you will be able to :   - Manage your campaigns and get the statistics   - Manage your contacts   - Send transactional Emails and SMS   - and much more...  You can download our wrappers at https://github.com/orgs/sendinblue  **Possible responses**   | Code | Message |   | :-------------: | ------------- |   | 200  | OK. Successful Request  |   | 201  | OK. Successful Creation |   | 202  | OK. Request accepted |   | 204  | OK. Successful Update/Deletion  |   | 400  | Error. Bad Request  |   | 401  | Error. Authentication Needed  |   | 402  | Error. Not enough credit, plan upgrade needed  |   | 403  | Error. Permission denied  |   | 404  | Error. Object does not exist |   | 405  | Error. Method not allowed  |   # noqa: E501

    OpenAPI spec version: 3.0.0
    Contact: contact@sendinblue.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from sib_api_v3_sdk.api_client import ApiClient


class ProcessApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_process(self, process_id, **kwargs):  # noqa: E501
        """Return the informations for a process  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_process(process_id, async=True)
        >>> result = thread.get()

        :param async bool
        :param int process_id: Id of the process (required)
        :return: GetProcess
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.get_process_with_http_info(process_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_process_with_http_info(process_id, **kwargs)  # noqa: E501
            return data

    def get_process_with_http_info(self, process_id, **kwargs):  # noqa: E501
        """Return the informations for a process  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_process_with_http_info(process_id, async=True)
        >>> result = thread.get()

        :param async bool
        :param int process_id: Id of the process (required)
        :return: GetProcess
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['process_id']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_process" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'process_id' is set
        if ('process_id' not in params or
                params['process_id'] is None):
            raise ValueError("Missing the required parameter `process_id` when calling `get_process`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'process_id' in params:
            path_params['processId'] = params['process_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api-key', 'partner-key']  # noqa: E501

        return self.api_client.call_api(
            '/processes/{processId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GetProcess',  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_processes(self, **kwargs):  # noqa: E501
        """Return all the processes for your account  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_processes(async=True)
        >>> result = thread.get()

        :param async bool
        :param int limit: Number limitation for the result returned
        :param int offset: Beginning point in the list to retrieve from.
        :return: GetProcesses
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.get_processes_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_processes_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_processes_with_http_info(self, **kwargs):  # noqa: E501
        """Return all the processes for your account  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_processes_with_http_info(async=True)
        >>> result = thread.get()

        :param async bool
        :param int limit: Number limitation for the result returned
        :param int offset: Beginning point in the list to retrieve from.
        :return: GetProcesses
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['limit', 'offset']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_processes" % key
                )
            params[key] = val
        del params['kwargs']

        if 'limit' in params and params['limit'] > 50:  # noqa: E501
            raise ValueError("Invalid value for parameter `limit` when calling `get_processes`, must be a value less than or equal to `50`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501
        if 'offset' in params:
            query_params.append(('offset', params['offset']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api-key', 'partner-key']  # noqa: E501

        return self.api_client.call_api(
            '/processes', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GetProcesses',  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    SendinBlue API

    SendinBlue provide a RESTFul API that can be used with any languages. With this API, you will be able to :   - Manage your campaigns and get the statistics   - Manage your contacts   - Send transactional Emails and SMS   - and much more...  You can download our wrappers at https://github.com/orgs/sendinblue  **Possible responses**   | Code | Message |   | :-------------: | ------------- |   | 200  | OK. Successful Request  |   | 201  | OK. Successful Creation |   | 202  | OK. Request accepted |   | 204  | OK. Successful Update/Deletion  |   | 400  | Error. Bad Request  |   | 401  | Error. Authentication Needed  |   | 402  | Error. Not enough credit, plan upgrade needed  |   | 403  | Error. Permission denied  |   | 404  | Error. Object does not exist |   | 405  | Error. Method not allowed  |   # noqa: E501

    OpenAPI spec version: 3.0.0
    Contact: contact@sendinblue.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from sib_api_v3_sdk.models.send_email_attachment import SendEmailAttachment  # noqa: F401,E501


class SendEmail(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'email_to': 'list[str]',
        'email_bcc': 'list[str]',
        'email_cc': 'list[str]',
        'reply_to': 'str',
        'attachment_url': 'str',
        'attachment': 'list[SendEmailAttachment]',
        'headers': 'object',
        'attributes': 'object',
        'tags': 'list[str]'
    }

    attribute_map = {
        'email_to': 'emailTo',
        'email_bcc': 'emailBcc',
        'email_cc': 'emailCc',
        'reply_to': 'replyTo',
        'attachment_url': 'attachmentUrl',
        'attachment': 'attachment',
        'headers': 'headers',
        'attributes': 'attributes',
        'tags': 'tags'
    }

    def __init__(self, email_to=None, email_bcc=None, email_cc=None, reply_to=None, attachment_url=None, attachment=None, headers=None, attributes=None, tags=None):  # noqa: E501
        """SendEmail - a model defined in Swagger"""  # noqa: E501

        self._email_to = None
        self._email_bcc = None
        self._email_cc = None
        self._reply_to = None
        self._attachment_url = None
        self._attachment = None
        self._headers = None
        self._attributes = None
        self._tags = None
        self.discriminator = None

        self.email_to = email_to
        if email_bcc is not None:
            self.email_bcc = email_bcc
        if email_cc is not None:
            self.email_cc = email_cc
        if reply_to is not None:
            self.reply_to = reply_to
        if attachment_url is not None:
            self.attachment_url = attachment_url
        if attachment is not None:
            self.attachment = attachment
        if headers is not None:
            self.headers = headers
        if attributes is not None:
            self.attributes = attributes
        if tags is not None:
            self.tags = tags

    @property
    def email_to(self):
        """Gets the email_to of this SendEmail.  # noqa: E501

        List of the email addresses of the recipients. For example, ['abc@example.com', 'asd@example.com'].  # noqa: E501

        :return: The email_to of this SendEmail.  # noqa: E501
        :rtype: list[str]
        """
        return self._email_to

    @email_to.setter
    def email_to(self, email_to):
        """Sets the email_to of this SendEmail.

        List of the email addresses of the recipients. For example, ['abc@example.com', 'asd@example.com'].  # noqa: E501

        :param email_to: The email_to of this SendEmail.  # noqa: E501
        :type: list[str]
        """
        if email_to is None:
            raise ValueError("Invalid value for `email_to`, must not be `None`")  # noqa: E501

        self._email_to = email_to

    @property
    def email_bcc(self):
        """Gets the email_bcc of this SendEmail.  # noqa: E501

        List of the email addresses of the recipients in bcc  # noqa: E501

        :return: The email_bcc of this SendEmail.  # noqa: E501
        :rtype: list[str]
        """
        return self._email_bcc

    @email_bcc.setter
    def email_bcc(self, email_bcc):
        """Sets the email_bcc of this SendEmail.

        List of the email addresses of the recipients in bcc  # noqa: E501

        :param email_bcc: The email_bcc of this SendEmail.  # noqa: E501
        :type: list[str]
        """

        self._email_bcc = email_bcc

    @property
    def email_cc(self):
        """Gets the email_cc of this SendEmail.  # noqa: E501

        List of the email addresses of the recipients in cc  # noqa: E501

        :return: The email_cc of this SendEmail.  # noqa: E501
        :rtype: list[str]
        """
        return self._email_cc

    @email_cc.setter
    def email_cc(self, email_cc):
        """Sets the email_cc of this SendEmail.

        List of the email addresses of the recipients in cc  # noqa: E501

        :param email_cc: The email_cc of this SendEmail.  # noqa: E501
        :type: list[str]
        """

        self._email_cc = email_cc

    @property
    def reply_to(self):
        """Gets the reply_to of this SendEmail.  # noqa: E501

        Email address which shall be used by campaign recipients to reply back  # noqa: E501

        :return: The reply_to of this SendEmail.  # noqa: E501
        :rtype: str
        """
        return self._reply_to

    @reply_to.setter
    def reply_to(self, reply_to):
        """Sets the reply_to of this SendEmail.

        Email address which shall be used by campaign recipients to reply back  # noqa: E501

        :param reply_to: The reply_to of this SendEmail.  # noqa: E501
        :type: str
        """

        self._reply_to = reply_to

    @property
    def attachment_url(self):
        """Gets the attachment_url of this SendEmail.  # noqa: E501

        Absolute url of the attachment (no local file). Extension allowed: xlsx, xls, ods, docx, docm, doc, csv, pdf, txt, gif, jpg, jpeg, png, tif, tiff, rtf, bmp, cgm, css, shtml, html, htm, zip, xml, ppt, pptx, tar, ez, ics, mobi, msg, pub and eps  # noqa: E501

        :return: The attachment_url of this SendEmail.  # noqa: E501
        :rtype: str
        """
        return self._attachment_url

    @attachment_url.setter
    def attachment_url(self, attachment_url):
        """Sets the attachment_url of this SendEmail.

        Absolute url of the attachment (no local file). Extension allowed: xlsx, xls, ods, docx, docm, doc, csv, pdf, txt, gif, jpg, jpeg, png, tif, tiff, rtf, bmp, cgm, css, shtml, html, htm, zip, xml, ppt, pptx, tar, ez, ics, mobi, msg, pub and eps  # noqa: E501

        :param attachment_url: The attachment_url of this SendEmail.  # noqa: E501
        :type: str
        """

        self._attachment_url = attachment_url

    @property
    def attachment(self):
        """Gets the attachment of this SendEmail.  # noqa: E501

        Pass the list of content (base64 encoded) and name of the attachment. For example, [{'content':'base64 encoded content 1', 'name':'attcahment1'}, {'content':'base64 encoded content 2', 'name':'attcahment2'}].  # noqa: E501

        :return: The attachment of this SendEmail.  # noqa: E501
        :rtype: list[SendEmailAttachment]
        """
        return self._attachment

    @attachment.setter
    def attachment(self, attachment):
        """Sets the attachment of this SendEmail.

        Pass the list of content (base64 encoded) and name of the attachment. For example, [{'content':'base64 encoded content 1', 'name':'attcahment1'}, {'content':'base64 encoded content 2', 'name':'attcahment2'}].  # noqa: E501

        :param attachment: The attachment of this SendEmail.  # noqa: E501
        :type: list[SendEmailAttachment]
        """

        self._attachment = attachment

    @property
    def headers(self):
        """Gets the headers of this SendEmail.  # noqa: E501

        Pass the set of headers that shall be sent along the mail headers in the original email. 'sender.ip' header can be set (only for dedicated ip users) to mention the IP to be used for sending transactional emails. For example, {'Content-Type':'text/html', 'charset':'iso-8859-1', 'sender.ip':'1.2.3.4'}  # noqa: E501

        :return: The headers of this SendEmail.  # noqa: E501
        :rtype: object
        """
        return self._headers

    @headers.setter
    def headers(self, headers):
        """Sets the headers of this SendEmail.

        Pass the set of headers that shall be sent along the mail headers in the original email. 'sender.ip' header can be set (only for dedicated ip users) to mention the IP to be used for sending transactional emails. For example, {'Content-Type':'text/html', 'charset':'iso-8859-1', 'sender.ip':'1.2.3.4'}  # noqa: E501

        :param headers: The headers of this SendEmail.  # noqa: E501
        :type: object
        """

        self._headers = headers

    @property
    def attributes(self):
        """Gets the attributes of this SendEmail.  # noqa: E501

        Pass the set of attributes to customize the template. For example, {'FNAME':'Joe', 'LNAME':'Doe'}  # noqa: E501

        :return: The attributes of this SendEmail.  # noqa: E501
        :rtype: object
        """
        return self._attributes

    @attributes.setter
    def attributes(self, attributes):
        """Sets the attributes of this SendEmail.

        Pass the set of attributes to customize the template. For example, {'FNAME':'Joe', 'LNAME':'Doe'}  # noqa: E501

        :param attributes: The attributes of this SendEmail.  # noqa: E501
        :type: object
        """

        self._attributes = attributes

    @property
    def tags(self):
        """Gets the tags of this SendEmail.  # noqa: E501

        Tag your emails to find them more easily  # noqa: E501

        :return: The tags of this SendEmail.  # noqa: E501
        :rtype: list[str]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """Sets the tags of this SendEmail.

        Tag your emails to find them more easily  # noqa: E501

        :param tags: The tags of this SendEmail.  # noqa: E501
        :type: list[str]
        """

        self._tags = tags

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SendEmail):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    SendinBlue API

    SendinBlue provide a RESTFul API that can be used with any languages. With this API, you will be able to :   - Manage your campaigns and get the statistics   - Manage your contacts   - Send transactional Emails and SMS   - and much more...  You can download our wrappers at https://github.com/orgs/sendinblue  **Possible responses**   | Code | Message |   | :-------------: | ------------- |   | 200  | OK. Successful Request  |   | 201  | OK. Successful Creation |   | 202  | OK. Request accepted |   | 204  | OK. Successful Update/Deletion  |   | 400  | Error. Bad Request  |   | 401  | Error. Authentication Needed  |   | 402  | Error. Not enough credit, plan upgrade needed  |   | 403  | Error. Permission denied  |   | 404  | Error. Object does not exist |   | 405  | Error. Method not allowed  |   # noqa: E501

    OpenAPI spec version: 3.0.0
    Contact: contact@sendinblue.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from sib_api_v3_sdk.models.get_attributes_enumeration import GetAttributesEnumeration  # noqa: F401,E501


class GetAttributesAttributes(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'category': 'str',
        'type': 'str',
        'enumeration': 'list[GetAttributesEnumeration]',
        'calculated_value': 'str'
    }

    attribute_map = {
        'name': 'name',
        'category': 'category',
        'type': 'type',
        'enumeration': 'enumeration',
        'calculated_value': 'calculatedValue'
    }

    def __init__(self, name=None, category=None, type=None, enumeration=None, calculated_value=None):  # noqa: E501
        """GetAttributesAttributes - a model defined in Swagger"""  # noqa: E501

        self._name = None
        self._category = None
        self._type = None
        self._enumeration = None
        self._calculated_value = None
        self.discriminator = None

        self.name = name
        self.category = category
        if type is not None:
            self.type = type
        if enumeration is not None:
            self.enumeration = enumeration
        if calculated_value is not None:
            self.calculated_value = calculated_value

    @property
    def name(self):
        """Gets the name of this GetAttributesAttributes.  # noqa: E501

        Name of the attribute  # noqa: E501

        :return: The name of this GetAttributesAttributes.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this GetAttributesAttributes.

        Name of the attribute  # noqa: E501

        :param name: The name of this GetAttributesAttributes.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def category(self):
        """Gets the category of this GetAttributesAttributes.  # noqa: E501

        Category of the attribute  # noqa: E501

        :return: The category of this GetAttributesAttributes.  # noqa: E501
        :rtype: str
        """
        return self._category

    @category.setter
    def category(self, category):
        """Sets the category of this GetAttributesAttributes.

        Category of the attribute  # noqa: E501

        :param category: The category of this GetAttributesAttributes.  # noqa: E501
        :type: str
        """
        if category is None:
            raise ValueError("Invalid value for `category`, must not be `None`")  # noqa: E501
        allowed_values = ["normal", "transactional", "category", "calculated", "global"]  # noqa: E501
        if category not in allowed_values:
            raise ValueError(
                "Invalid value for `category` ({0}), must be one of {1}"  # noqa: E501
                .format(category, allowed_values)
            )

        self._category = category

    @property
    def type(self):
        """Gets the type of this GetAttributesAttributes.  # noqa: E501

        Type of the attribute  # noqa: E501

        :return: The type of this GetAttributesAttributes.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this GetAttributesAttributes.

        Type of the attribute  # noqa: E501

        :param type: The type of this GetAttributesAttributes.  # noqa: E501
        :type: str
        """
        allowed_values = ["text", "date", "float", "id", "boolean"]  # noqa: E501
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    @property
    def enumeration(self):
        """Gets the enumeration of this GetAttributesAttributes.  # noqa: E501

        Parameter only available for \"category\" type attributes.  # noqa: E501

        :return: The enumeration of this GetAttributesAttributes.  # noqa: E501
        :rtype: list[GetAttributesEnumeration]
        """
        return self._enumeration

    @enumeration.setter
    def enumeration(self, enumeration):
        """Sets the enumeration of this GetAttributesAttributes.

        Parameter only available for \"category\" type attributes.  # noqa: E501

        :param enumeration: The enumeration of this GetAttributesAttributes.  # noqa: E501
        :type: list[GetAttributesEnumeration]
        """

        self._enumeration = enumeration

    @property
    def calculated_value(self):
        """Gets the calculated_value of this GetAttributesAttributes.  # noqa: E501

        Calculated value formula  # noqa: E501

        :return: The calculated_value of this GetAttributesAttributes.  # noqa: E501
        :rtype: str
        """
        return self._calculated_value

    @calculated_value.setter
    def calculated_value(self, calculated_value):
        """Sets the calculated_value of this GetAttributesAttributes.

        Calculated value formula  # noqa: E501

        :param calculated_value: The calculated_value of this GetAttributesAttributes.  # noqa: E501
        :type: str
        """

        self._calculated_value = calculated_value

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GetAttributesAttributes):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    SendinBlue API

    SendinBlue provide a RESTFul API that can be used with any languages. With this API, you will be able to :   - Manage your campaigns and get the statistics   - Manage your contacts   - Send transactional Emails and SMS   - and much more...  You can download our wrappers at https://github.com/orgs/sendinblue  **Possible responses**   | Code | Message |   | :-------------: | ------------- |   | 200  | OK. Successful Request  |   | 201  | OK. Successful Creation |   | 202  | OK. Request accepted |   | 204  | OK. Successful Update/Deletion  |   | 400  | Error. Bad Request  |   | 401  | Error. Authentication Needed  |   | 402  | Error. Not enough credit, plan upgrade needed  |   | 403  | Error. Permission denied  |   | 404  | Error. Object does not exist |   | 405  | Error. Method not allowed  |   # noqa: E501

    OpenAPI spec version: 3.0.0
    Contact: contact@sendinblue.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class SendSms(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'reference': 'str',
        'message_id': 'int',
        'sms_count': 'int',
        'used_credits': 'float',
        'remaining_credits': 'float'
    }

    attribute_map = {
        'reference': 'reference',
        'message_id': 'messageId',
        'sms_count': 'smsCount',
        'used_credits': 'usedCredits',
        'remaining_credits': 'remainingCredits'
    }

    def __init__(self, reference=None, message_id=None, sms_count=None, used_credits=None, remaining_credits=None):  # noqa: E501
        """SendSms - a model defined in Swagger"""  # noqa: E501

        self._reference = None
        self._message_id = None
        self._sms_count = None
        self._used_credits = None
        self._remaining_credits = None
        self.discriminator = None

        self.reference = reference
        self.message_id = message_id
        if sms_count is not None:
            self.sms_count = sms_count
        if used_credits is not None:
            self.used_credits = used_credits
        if remaining_credits is not None:
            self.remaining_credits = remaining_credits

    @property
    def reference(self):
        """Gets the reference of this SendSms.  # noqa: E501


        :return: The reference of this SendSms.  # noqa: E501
        :rtype: str
        """
        return self._reference

    @reference.setter
    def reference(self, reference):
        """Sets the reference of this SendSms.


        :param reference: The reference of this SendSms.  # noqa: E501
        :type: str
        """
        if reference is None:
            raise ValueError("Invalid value for `reference`, must not be `None`")  # noqa: E501

        self._reference = reference

    @property
    def message_id(self):
        """Gets the message_id of this SendSms.  # noqa: E501


        :return: The message_id of this SendSms.  # noqa: E501
        :rtype: int
        """
        return self._message_id

    @message_id.setter
    def message_id(self, message_id):
        """Sets the message_id of this SendSms.


        :param message_id: The message_id of this SendSms.  # noqa: E501
        :type: int
        """
        if message_id is None:
            raise ValueError("Invalid value for `message_id`, must not be `None`")  # noqa: E501

        self._message_id = message_id

    @property
    def sms_count(self):
        """Gets the sms_count of this SendSms.  # noqa: E501

        Count of SMS's to send multiple text messages  # noqa: E501

        :return: The sms_count of this SendSms.  # noqa: E501
        :rtype: int
        """
        return self._sms_count

    @sms_count.setter
    def sms_count(self, sms_count):
        """Sets the sms_count of this SendSms.

        Count of SMS's to send multiple text messages  # noqa: E501

        :param sms_count: The sms_count of this SendSms.  # noqa: E501
        :type: int
        """

        self._sms_count = sms_count

    @property
    def used_credits(self):
        """Gets the used_credits of this SendSms.  # noqa: E501

        SMS credits used per text message  # noqa: E501

        :return: The used_credits of this SendSms.  # noqa: E501
        :rtype: float
        """
        return self._used_credits

    @used_credits.setter
    def used_credits(self, used_credits):
        """Sets the used_credits of this SendSms.

        SMS credits used per text message  # noqa: E501

        :param used_credits: The used_credits of this SendSms.  # noqa: E501
        :type: float
        """

        self._used_credits = used_credits

    @property
    def remaining_credits(self):
        """Gets the remaining_credits of this SendSms.  # noqa: E501

        Remaining SMS credits of the user  # noqa: E501

        :return: The remaining_credits of this SendSms.  # noqa: E501
        :rtype: float
        """
        return self._remaining_credits

    @remaining_credits.setter
    def remaining_credits(self, remaining_credits):
        """Sets the remaining_credits of this SendSms.

        Remaining SMS credits of the user  # noqa: E501

        :param remaining_credits: The remaining_credits of this SendSms.  # noqa: E501
        :type: float
        """

        self._remaining_credits = remaining_credits

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SendSms):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
